pub enum LeadingEigenvectorEvent {
StartFull,
StartGiven {
communities: i64,
},
Split {
community: i64,
},
Failed {
community: i64,
},
}Expand description
One step of the history of Graph::community_leading_eigenvector
(igraph_leading_eigenvector_community_history_t).
Variants
StartFull
The algorithm started from the connected components of the graph.
StartGiven
The algorithm started from a given partition with this many communities.
Split
A community was split in two: the first part keeps the id, the second one gets the number of communities before the split as id.
Failed
Splitting the community would not increase modularity.