pub struct Clustering {
pub membership: Vec<i64>,
pub modularity: f64,
}Expand description
A flat partition of the vertices together with its modularity.
Returned by Graph::community_optimal_modularity.
Fields
membership: Vec<i64>Community id of each vertex, numbered from zero.
modularity: f64Modularity of the partition (NaN for graphs without edges).
Implementations
Sourceimpl Clustering
impl Clustering
Sourcepub fn num_communities(&self) -> usize
pub fn num_communities(&self) -> usize
Number of communities in membership.
Sourcepub fn communities(&self) -> Vec<Vec<VertexId>>
pub fn communities(&self) -> Vec<Vec<VertexId>>
The vertices of each community, indexed by community id.