EdgeBetweennessCommunities

Struct EdgeBetweennessCommunities 

pub struct EdgeBetweennessCommunities {
    pub removed_edges: Vec<EdgeId>,
    pub edge_betweenness: Vec<f64>,
    pub merges: Vec<(i64, i64)>,
    pub bridges: Vec<i64>,
    pub modularity: Vec<f64>,
    pub membership: Vec<i64>,
}
Result of the Girvan–Newman algorithm, see Graph::community_edge_betweenness.

Fields

removed_edges: Vec<EdgeId>

The ids of the removed edges, in order of removal.

edge_betweenness: Vec<f64>

Betweenness of each removed edge at the moment of its removal (not divided by the weights).

merges: Vec<(i64, i64)>

The dendrogram, obtained by replaying the removals backwards.

bridges: Vec<i64>

Indices into removed_edges of the edges whose removal split a component, in reverse order.

modularity: Vec<f64>

Modularity of each division: before the first merge (all components split into single vertices) and after each merge, i.e. merges.len() + 1 values in the order of merges.

membership: Vec<i64>

Membership vector of the division with the highest modularity.

Implementations

Source

impl EdgeBetweennessCommunities

pub fn num_communities(&self) -> usize

Number of communities in membership.

pub fn sizes(&self) -> Vec<usize>

Size of each community, indexed by community id.

pub fn communities(&self) -> Vec<Vec<VertexId>>

The vertices of each community, indexed by community id.