pub struct EdgeRemovalMerges {
pub dendrogram: Dendrogram,
pub bridges: Vec<i64>,
}Expand description
Result of Graph::community_eb_get_merges.
Fields
dendrogram: DendrogramThe dendrogram with its modularity values and best membership.
bridges: Vec<i64>Indices into the given edge sequence of the edges whose removal split a component, in reverse order.