pub struct HrgConsensus {
pub parents: Vec<i64>,
pub weights: Vec<f64>,
pub hrg: Hrg,
}Expand description
Result of Graph::hrg_consensus.
Fields
parents: Vec<i64>Parent of each node of the consensus tree (-1 for roots): ids
0..n are the vertices of the graph, larger ids are vertex groups.
weights: Vec<f64>For each internal node of the consensus tree (ids n..), how many
times its split occurred in the samples.
hrg: HrgThe model the sampling started from: a copy of the given start model, or the model fitted to equilibrium when none was given.