pub struct HrgPrediction {
pub edges: Vec<(VertexId, VertexId)>,
pub prob: Vec<f64>,
pub hrg: Hrg,
}Expand description
Result of Graph::hrg_predict.
Fields
edges: Vec<(VertexId, VertexId)>The candidate missing edges, most likely first.
prob: Vec<f64>The estimated probability of each candidate edge.
hrg: HrgThe model the sampling started from: a copy of the given start model, or the model fitted to equilibrium when none was given.