pub struct InfomapOptions {
pub trials: usize,
pub regularized: bool,
pub regularization_strength: f64,
}Expand description
Options of Graph::community_infomap.
Fields
trials: usizeNumber of attempts to partition the network, the best one is kept
(default 10, at least 1 and at most u32::MAX).
regularized: boolAdd a Bayesian prior network to avoid overfitting missing links
(default false).
regularization_strength: f64Multiplier of the default regularization strength (default 1.0).