LeadingEigenvectorStep

Struct LeadingEigenvectorStep 

pub struct LeadingEigenvectorStep<'a> { /* private fields */ }
The state passed to the callback of Graph::community_leading_eigenvector_with after each eigenvector computation.

Implementations

Source

impl LeadingEigenvectorStep<'_>

pub fn membership(&self) -> &[i64]

The current membership vector, before applying the split implied by this eigenvector.

pub fn community(&self) -> i64

The id of the community the algorithm is trying to split.

pub fn eigenvalue(&self) -> f64

The leading eigenvalue just found; the community is split only if it is positive.

pub fn eigenvector(&self) -> &[f64]

The corresponding eigenvector, with one element per vertex of the community (in increasing vertex id order).

pub fn multiply(&self, x: &[f64]) -> Result<Vec<f64>>

Multiplies x by the (generalized) modularity matrix of the community being split, i.e. runs the ARPACK matrix-vector product igraph used to find this eigenvector. x must have the length of eigenvector.

For instance step.multiply(step.eigenvector()) is eigenvalue * eigenvector up to numerical accuracy.

Errors

If x has a wrong length.