LeidenOptions

Struct LeidenOptions 

pub struct LeidenOptions<'a> {
    pub resolution: f64,
    pub beta: f64,
    pub iterations: Option<u32>,
    pub initial: Option<&'a [i64]>,
}
Fields

resolution: f64

Resolution parameter γ (default 1.0). Note that for the raw Graph::community_leiden interface, modularity is obtained with degrees as vertex weights and γ = 1 / (2m).

beta: f64

Randomness in the refinement step (default 0.01).

iterations: Option<u32>

Number of iterations of the core algorithm (default Some(2)); None iterates until an iteration does not change the partition.

initial: Option<&'a [i64]>

Starting partition (default None: singletons).

Implementations

Source

impl<'a> LeidenOptions<'a>

pub fn with_resolution(self, resolution: f64) -> Self

Sets the resolution parameter.

pub fn with_beta(self, beta: f64) -> Self

Sets the refinement randomness beta.

pub fn with_iterations(self, iterations: Option<u32>) -> Self

Sets the number of iterations (None: until convergence).

pub fn with_initial(self, initial: &'a [i64]) -> Self

Sets the starting partition.